package VMOMI::HostIpConfigIpV6AddressStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
